@@ -1,21 +1,25 @@
 import typer
 
-from eoplatform.main import *
-from eoplatform.main import download
 from eoplatform.main import info
+from eoplatform.platforms.download.downloadControl import download
 
 
 app = typer.Typer()
 
 
 @app.command("info")
-def platform_info(
+def info_controller(
     name: str,
     only_bands: bool = typer.Option(False, "--only-bands /", "-b /"),
     show_description: bool = typer.Option(True, " /--no-description", " /-nd"),
 ) -> None:
 
-    info(name=name, only_bands=only_bands, show_description=show_description)
+    info(
+        name=name.upper().strip(),
+        only_bands=only_bands,
+        show_description=show_description,
+    )
+
     return None
 
 
